@@ -7,6 +7,7 @@
 #' @examples
 #' transaction_counter(leagueId = "42654852")
 #' @importFrom tibble as_tibble
+#' @family league functions
 #' @export
 transaction_counter <- function(leagueId = ffl_id(), leagueHistory = FALSE, ...) {
   dat <- ffl_api(leagueId, leagueHistory, view = "mTeam", ...)
@@ -41,3 +42,15 @@ out_trans <- function(teams, y = NULL, w = NULL) {
   )
   as_tibble(x)
 }
+
+#' @rdname transaction_counter
+#' @family player functions
+#' @export
+budget_summary <- function(leagueId = ffl_id(), leagueHistory = FALSE, ...) {
+  out <- transaction_counter(
+    leagueId = leagueId,
+    leagueHistory = leagueHistory,
+    ...
+  )
+  out[order(out$waiverRank), c(1:6)]
+}
